
#include "FIPCB.h"

/* ----- SPLB process ----- */
void FIPCB::SPLB()
{
  /* ----- reset block ----- */
  SPLB_Reset();

  sc_uint<SPLB_AWIDTH> l_Address = 0;
  sc_uint<SPLB_MID_WIDTH> l_MasterID = 0;
  sc_uint<SPLB_NUM_MASTERS> l_Busy = 0;

  sc_uint<SPLB_DWIDTH/8> l_BE = 0;
  sc_uint<SPLB_DWIDTH> l_Buffer = 0;

  wait();
  while( true )
  {
    if( F_PLB_PAValid.read() == true ) //request
    {
      //address
      l_Address = F_PLB_ABus.read();
      if( l_Address.range(31,16) == 0xCFC0  )
      {
        F_Sl_addrAck.write(true);

        //busy indicator
        l_MasterID = F_PLB_masterID.read();
        l_Busy = 1;
        l_Busy = l_Busy << l_MasterID;
        F_Sl_MBusy.write(l_Busy);

        if( F_PLB_RNW.read() == true ) //read
        {
          l_Buffer = SPLB_Register0;
          F_Sl_rdDBus.write(l_Buffer);

          wait();
          F_Sl_addrAck.write(false);
          wait();
          F_Sl_rdComp.write(true);
          wait();
          F_Sl_rdDAck.write(true);
        }
        else //write
        {
          l_LEDs.range(7,4) = F_PLB_BE.read();

          SPLB_Register0 = F_PLB_wrDBus.read();
		  
          F_Sl_wrComp.write(true);
          F_Sl_wrDAck.write(true);
        }

        wait();

        //transfer complete
        F_Sl_addrAck.write(false);
        F_Sl_wrComp.write(false);
        F_Sl_wrDAck.write(false);
        F_Sl_rdDAck.write(false);
        F_Sl_rdComp.write(false);
        F_Sl_rdDBus.write(0);
        l_Busy = 0;
        F_Sl_MBusy.write(l_Busy);
        l_Buffer = 0;
      }
    }
	
    wait();
  }
}

void FIPCB::SPLB_Reset()
{
  F_Sl_addrAck.write(false);
  F_Sl_SSize.write(0);
  F_Sl_wait.write(false);
  F_Sl_rearbitrate.write(false);
  F_Sl_wrDAck.write(false);
  F_Sl_wrComp.write(false);
  F_Sl_wrBTerm.write(false);
  F_Sl_rdDBus.write(0);
  F_Sl_rdWdAddr.write(0);
  F_Sl_rdDAck.write(false);
  F_Sl_rdComp.write(false);
  F_Sl_rdBTerm.write(false);
  F_Sl_MBusy.write(0);
  F_Sl_MWrErr.write(0);
  F_Sl_MRdErr.write(0);
  F_Sl_MIRQ.write(0);
}

void FIPCB::setSPLB_Register( sc_uint<2> index,
    sc_uint<SPLB_DWIDTH> data )
{
  switch(index)
  {
  case 0:
    SPLB_Register0 = data;
    break;
  case 1:
    SPLB_Register1 = data;
    break;
  case 2:
    SPLB_Register2 = data;
    break;
  case 3:
    SPLB_Register3 = data;
    break;
  default:
    return;
  }
}

sc_uint<SPLB_DWIDTH> FIPCB::getSPLB_Register( sc_uint<2> index )
{
  switch(index)
  {
  case 0:
    return SPLB_Register0;
  case 1:
    return SPLB_Register1;
  case 2:
    return SPLB_Register2;
  case 3:
    return SPLB_Register3;
  default:
    return 0;
  }
}
