#ifndef FIPCB_H
#define FIPCB_H

/* ---- PLB slave constants ---- */
#define SPLB_AWIDTH 32 //address bus width
#define SPLB_DWIDTH 32 //data bus width
#define SPLB_MID_WIDTH 2 //master ID bus width
#define SPLB_NUM_MASTERS 4 //number of masters
#define SPLB_BASEADDR 0xCFC00000
#define SPLB_HIGHADDR 0xCFC0FFFF

#include <systemc.h>

SC_MODULE( FIPCB )
{
  /* ----- PLB slave ports ----- */
  sc_in<bool> F_SPLB_Clk; //PLB main bus clock
  sc_in<bool> F_SPLB_Rst; //PLB main bus reset
  sc_in<sc_uint<SPLB_AWIDTH> > F_PLB_ABus; //PLB address bus
  sc_in<sc_uint<SPLB_AWIDTH> > F_PLB_UABus; //PLB upper address bus
  sc_in<bool> F_PLB_PAValid; //PLB primary address valid indicator
  sc_in<bool> F_PLB_SAValid; //PLB secondary address valid indicator
  sc_in<bool> F_PLB_rdPrim; //PLB secondary to primary read request indicator
  sc_in<bool> F_PLB_wrPrim; //PLB secondary to primary write request indicator
  sc_in<sc_uint<SPLB_MID_WIDTH> > F_PLB_masterID; //PLB current master identifier
  sc_in<bool> F_PLB_abort; //PLB abort request indicator
  sc_in<bool> F_PLB_busLock; //PLB bus lock
  sc_in<bool> F_PLB_RNW; //PLB read/not write
  sc_in<sc_uint<SPLB_DWIDTH/8> > F_PLB_BE; //PLB byte enables
  sc_in<sc_uint<2> > F_PLB_MSize; //PLB master data bus size
  sc_in<sc_uint<4> > F_PLB_size; //PLB transfer size
  sc_in<sc_uint<3> > F_PLB_type; //PLB transfer type
  sc_in<bool> F_PLB_lockErr; //PLB lock error indicator
  sc_in<sc_uint<SPLB_DWIDTH> > F_PLB_wrDBus; //PLB write data bus
  sc_in<bool> F_PLB_wrBurst; //PLB burst write transfer indicator
  sc_in<bool> F_PLB_rdBurst; //PLB burst read transfer indicator
  sc_in<bool> F_PLB_wrPendReq; //PLB write pending bus request indicator
  sc_in<bool> F_PLB_rdPendReq; //PLB read pending bus request indicator
  sc_in<sc_uint<2> > F_PLB_wrPendPri; //PLB write pending request priority
  sc_in<sc_uint<2> > F_PLB_rdPendPri; //PLB read pending request priority
  sc_in<sc_uint<2> > F_PLB_reqPri; //PLB current request priority
  sc_in<sc_uint<16> > F_PLB_TAttribute; //PLB transfer attribute

  sc_out<bool> F_Sl_addrAck; //Slave address acknowledge
  sc_out<sc_uint<2> > F_Sl_SSize; //Slave data bus size
  sc_out<bool> F_Sl_wait; //Slave wait indicator
  sc_out<bool> F_Sl_rearbitrate; //Slave re-arbitrate bus indicator
  sc_out<bool> F_Sl_wrDAck; //Slave write data acknowledge
  sc_out<bool> F_Sl_wrComp; //Slave write transfer complete indicator
  sc_out<bool> F_Sl_wrBTerm; //Slave terminate write burst transfer
  sc_out<sc_uint<SPLB_DWIDTH> > F_Sl_rdDBus; //Slave read data bus
  sc_out<sc_uint<4> > F_Sl_rdWdAddr; //Slave read word address
  sc_out<bool> F_Sl_rdDAck; //Slave read data acknowledge
  sc_out<bool> F_Sl_rdComp; //Slave read transfer complete indicator
  sc_out<bool> F_Sl_rdBTerm; //Slave terminate read burst transfer
  sc_out<sc_uint<SPLB_NUM_MASTERS> > F_Sl_MBusy; //Slave busy indicator
  sc_out<sc_uint<SPLB_NUM_MASTERS> > F_Sl_MWrErr; //Slave write error indicator
  sc_out<sc_uint<SPLB_NUM_MASTERS> > F_Sl_MRdErr; //Slave read error indicator
  sc_out<sc_uint<SPLB_NUM_MASTERS> > F_Sl_MIRQ; //Slave interrupt indicator

  /* ----- constructor ----- */
  SC_CTOR( FIPCB )
  {
     /* ----- process definitions ----- */
     SC_CTHREAD( SPLB, F_SPLB_Clk.pos() );
       reset_signal_is( F_SPLB_Rst, true );
  }

private:
  /* ----- processes ----- */
  void SPLB();

  /* ----- signals ----- */
  sc_signal<sc_uint<SPLB_DWIDTH> > SPLB_Register0;
  sc_signal<sc_uint<SPLB_DWIDTH> > SPLB_Register1;
  sc_signal<sc_uint<SPLB_DWIDTH> > SPLB_Register2;
  sc_signal<sc_uint<SPLB_DWIDTH> > SPLB_Register3;

  /* ----- methods ----- */
  void SPLB_Reset();

  void setSPLB_Register( sc_uint<2> index,
      sc_uint<SPLB_DWIDTH> data );
  sc_uint<SPLB_DWIDTH> getSPLB_Register( sc_uint<2> index );
};

#endif
