------------------------------------------------------------------------------
-- fipcb_slave.vhd - entity/architecture pair
------------------------------------------------------------------------------
-- IMPORTANT:
-- DO NOT MODIFY THIS FILE EXCEPT IN THE DESIGNATED SECTIONS.
--
-- SEARCH FOR --USER TO DETERMINE WHERE CHANGES ARE ALLOWED.
--
-- TYPICALLY, THE ONLY ACCEPTABLE CHANGES INVOLVE ADDING NEW
-- PORTS AND GENERICS THAT GET PASSED THROUGH TO THE INSTANTIATION
-- OF THE USER_LOGIC ENTITY.
------------------------------------------------------------------------------
--
-- ***************************************************************************
-- ** Copyright (c) 1995-2009 Xilinx, Inc.  All rights reserved.            **
-- **                                                                       **
-- ** Xilinx, Inc.                                                          **
-- ** XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS"         **
-- ** AS A COURTESY TO YOU, SOLELY FOR USE IN DEVELOPING PROGRAMS AND       **
-- ** SOLUTIONS FOR XILINX DEVICES.  BY PROVIDING THIS DESIGN, CODE,        **
-- ** OR INFORMATION AS ONE POSSIBLE IMPLEMENTATION OF THIS FEATURE,        **
-- ** APPLICATION OR STANDARD, XILINX IS MAKING NO REPRESENTATION           **
-- ** THAT THIS IMPLEMENTATION IS FREE FROM ANY CLAIMS OF INFRINGEMENT,     **
-- ** AND YOU ARE RESPONSIBLE FOR OBTAINING ANY RIGHTS YOU MAY REQUIRE      **
-- ** FOR YOUR IMPLEMENTATION.  XILINX EXPRESSLY DISCLAIMS ANY              **
-- ** WARRANTY WHATSOEVER WITH RESPECT TO THE ADEQUACY OF THE               **
-- ** IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR        **
-- ** REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE FROM CLAIMS OF       **
-- ** INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS       **
-- ** FOR A PARTICULAR PURPOSE.                                             **
-- **                                                                       **
-- ***************************************************************************
--
------------------------------------------------------------------------------
-- Filename:          fipcb_slave.vhd
-- Version:           1.00.a
-- Description:       Top level design, instantiates library components and user logic.
-- Date:              Wed Mar 24 17:24:21 2010 (by Create and Import Peripheral Wizard)
-- VHDL Standard:     VHDL'93
------------------------------------------------------------------------------
-- Naming Conventions:
--   active low signals:                    "*_n"
--   clock signals:                         "clk", "clk_div#", "clk_#x"
--   reset signals:                         "rst", "rst_n"
--   generics:                              "C_*"
--   user defined types:                    "*_TYPE"
--   state machine next state:              "*_ns"
--   state machine current state:           "*_cs"
--   combinatorial signals:                 "*_com"
--   pipelined or register delay signals:   "*_d#"
--   counter signals:                       "*cnt*"
--   clock enable signals:                  "*_ce"
--   internal version of output port:       "*_i"
--   device pins:                           "*_pin"
--   ports:                                 "- Names begin with Uppercase"
--   processes:                             "*_PROCESS"
--   component instantiations:              "<ENTITY_>I_<#|FUNC>"
------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;

------------------------------------------------------------------------------
-- Entity section
------------------------------------------------------------------------------
-- Definition of Generics:
--   C_BASEADDR                   -- PLBv46 slave: base address
--   C_HIGHADDR                   -- PLBv46 slave: high address
--   C_SPLB_AWIDTH                -- PLBv46 slave: address bus width
--   C_SPLB_DWIDTH                -- PLBv46 slave: data bus width
--   C_SPLB_NUM_MASTERS           -- PLBv46 slave: Number of masters
--   C_SPLB_MID_WIDTH             -- PLBv46 slave: master ID bus width
--   C_SPLB_NATIVE_DWIDTH         -- PLBv46 slave: internal native data bus width
--   C_SPLB_P2P                   -- PLBv46 slave: point to point interconnect scheme
--   C_SPLB_SUPPORT_BURSTS        -- PLBv46 slave: support bursts
--   C_SPLB_SMALLEST_MASTER       -- PLBv46 slave: width of the smallest master
--   C_SPLB_CLK_PERIOD_PS         -- PLBv46 slave: bus clock in picoseconds
--   C_INCLUDE_DPHASE_TIMER       -- PLBv46 slave: Data Phase Timer configuration; 0 = exclude timer, 1 = include timer
--   C_FAMILY                     -- Xilinx FPGA family
--
-- Definition of Ports:
--   SPLB_Clk                     -- PLB main bus clock
--   SPLB_Rst                     -- PLB main bus reset
--   PLB_ABus                     -- PLB address bus
--   PLB_UABus                    -- PLB upper address bus
--   PLB_PAValid                  -- PLB primary address valid indicator
--   PLB_SAValid                  -- PLB secondary address valid indicator
--   PLB_rdPrim                   -- PLB secondary to primary read request indicator
--   PLB_wrPrim                   -- PLB secondary to primary write request indicator
--   PLB_masterID                 -- PLB current master identifier
--   PLB_abort                    -- PLB abort request indicator
--   PLB_busLock                  -- PLB bus lock
--   PLB_RNW                      -- PLB read/not write
--   PLB_BE                       -- PLB byte enables
--   PLB_MSize                    -- PLB master data bus size
--   PLB_size                     -- PLB transfer size
--   PLB_type                     -- PLB transfer type
--   PLB_lockErr                  -- PLB lock error indicator
--   PLB_wrDBus                   -- PLB write data bus
--   PLB_wrBurst                  -- PLB burst write transfer indicator
--   PLB_rdBurst                  -- PLB burst read transfer indicator
--   PLB_wrPendReq                -- PLB write pending bus request indicator
--   PLB_rdPendReq                -- PLB read pending bus request indicator
--   PLB_wrPendPri                -- PLB write pending request priority
--   PLB_rdPendPri                -- PLB read pending request priority
--   PLB_reqPri                   -- PLB current request priority
--   PLB_TAttribute               -- PLB transfer attribute
--   Sl_addrAck                   -- Slave address acknowledge
--   Sl_SSize                     -- Slave data bus size
--   Sl_wait                      -- Slave wait indicator
--   Sl_rearbitrate               -- Slave re-arbitrate bus indicator
--   Sl_wrDAck                    -- Slave write data acknowledge
--   Sl_wrComp                    -- Slave write transfer complete indicator
--   Sl_wrBTerm                   -- Slave terminate write burst transfer
--   Sl_rdDBus                    -- Slave read data bus
--   Sl_rdWdAddr                  -- Slave read word address
--   Sl_rdDAck                    -- Slave read data acknowledge
--   Sl_rdComp                    -- Slave read transfer complete indicator
--   Sl_rdBTerm                   -- Slave terminate read burst transfer
--   Sl_MBusy                     -- Slave busy indicator
--   Sl_MWrErr                    -- Slave write error indicator
--   Sl_MRdErr                    -- Slave read error indicator
--   Sl_MIRQ                      -- Slave interrupt indicator
------------------------------------------------------------------------------

entity fipcb_slave is
  generic
  (
    -- ADD USER GENERICS BELOW THIS LINE ---------------
    --USER generics added here
    -- ADD USER GENERICS ABOVE THIS LINE ---------------

    -- DO NOT EDIT BELOW THIS LINE ---------------------
    -- Bus protocol parameters, do not add to or delete
    C_BASEADDR                     : std_logic_vector     := X"FFFFFFFF";
    C_HIGHADDR                     : std_logic_vector     := X"00000000";
    C_SPLB_AWIDTH                  : integer              := 32;
    C_SPLB_DWIDTH                  : integer              := 32;
    C_SPLB_NUM_MASTERS             : integer              := 4;
    C_SPLB_MID_WIDTH               : integer              := 2;
    C_SPLB_NATIVE_DWIDTH           : integer              := 32;
    C_SPLB_P2P                     : integer              := 0;
    C_SPLB_SUPPORT_BURSTS          : integer              := 0;
    C_SPLB_SMALLEST_MASTER         : integer              := 128;
    C_SPLB_CLK_PERIOD_PS           : integer              := 10000;
    C_INCLUDE_DPHASE_TIMER         : integer              := 0;
    C_FAMILY                       : string               := "virtex5"
    -- DO NOT EDIT ABOVE THIS LINE ---------------------
  );
  port
  (
    -- ADD USER PORTS BELOW THIS LINE ------------------
    LEDs : out std_logic_vector(0 to 7);
    -- ADD USER PORTS ABOVE THIS LINE ------------------

    -- DO NOT EDIT BELOW THIS LINE ---------------------
    -- Bus protocol ports, do not add to or delete
    SPLB_Clk                       : in  std_logic;
    SPLB_Rst                       : in  std_logic;
    PLB_ABus                       : in  std_logic_vector(0 to 31);
    PLB_UABus                      : in  std_logic_vector(0 to 31);
    PLB_PAValid                    : in  std_logic;
    PLB_SAValid                    : in  std_logic;
    PLB_rdPrim                     : in  std_logic;
    PLB_wrPrim                     : in  std_logic;
    PLB_masterID                   : in  std_logic_vector(0 to C_SPLB_MID_WIDTH-1);
    PLB_abort                      : in  std_logic;
    PLB_busLock                    : in  std_logic;
    PLB_RNW                        : in  std_logic;
    PLB_BE                         : in  std_logic_vector(0 to C_SPLB_DWIDTH/8-1);
    PLB_MSize                      : in  std_logic_vector(0 to 1);
    PLB_size                       : in  std_logic_vector(0 to 3);
    PLB_type                       : in  std_logic_vector(0 to 2);
    PLB_lockErr                    : in  std_logic;
    PLB_wrDBus                     : in  std_logic_vector(0 to C_SPLB_DWIDTH-1);
    PLB_wrBurst                    : in  std_logic;
    PLB_rdBurst                    : in  std_logic;
    PLB_wrPendReq                  : in  std_logic;
    PLB_rdPendReq                  : in  std_logic;
    PLB_wrPendPri                  : in  std_logic_vector(0 to 1);
    PLB_rdPendPri                  : in  std_logic_vector(0 to 1);
    PLB_reqPri                     : in  std_logic_vector(0 to 1);
    PLB_TAttribute                 : in  std_logic_vector(0 to 15);
    Sl_addrAck                     : out std_logic;
    Sl_SSize                       : out std_logic_vector(0 to 1);
    Sl_wait                        : out std_logic;
    Sl_rearbitrate                 : out std_logic;
    Sl_wrDAck                      : out std_logic;
    Sl_wrComp                      : out std_logic;
    Sl_wrBTerm                     : out std_logic;
    Sl_rdDBus                      : out std_logic_vector(0 to C_SPLB_DWIDTH-1);
    Sl_rdWdAddr                    : out std_logic_vector(0 to 3);
    Sl_rdDAck                      : out std_logic;
    Sl_rdComp                      : out std_logic;
    Sl_rdBTerm                     : out std_logic;
    Sl_MBusy                       : out std_logic_vector(0 to C_SPLB_NUM_MASTERS-1);
    Sl_MWrErr                      : out std_logic_vector(0 to C_SPLB_NUM_MASTERS-1);
    Sl_MRdErr                      : out std_logic_vector(0 to C_SPLB_NUM_MASTERS-1);
    Sl_MIRQ                        : out std_logic_vector(0 to C_SPLB_NUM_MASTERS-1)
    -- DO NOT EDIT ABOVE THIS LINE ---------------------
  );

  attribute SIGIS : string;
  attribute SIGIS of SPLB_Clk      : signal is "CLK";
  attribute SIGIS of SPLB_Rst      : signal is "RST";

end entity fipcb_slave;

------------------------------------------------------------------------------
-- Architecture section
------------------------------------------------------------------------------

architecture IMP of fipcb_slave is
function std_logic_to_bool (ARG: STD_LOGIC) return BOOLEAN is 
	  variable result : BOOLEAN; 
	begin
	  if arg = '1'
	  then
		 result := true;
	  else
		 result := false;
	  end if;
	  return result;
	end;

	function bool_to_std_logic (ARG: BOOLEAN) return STD_LOGIC is 
	  variable result : STD_LOGIC; 
	begin
	  if arg
	  then
		 result := '1';
	  else
		 result := '0';
	  end if;
	  return result;
	end;
	
	component FIPCB
		port(
			F_SPLB_Clk : in BOOLEAN ; 
			F_SPLB_Rst : in BOOLEAN ; 
			F_PLB_ABus : in UNSIGNED ( 31 downto 0 ) ; 
			F_PLB_UABus : in UNSIGNED ( 31 downto 0 ) ; 
			F_PLB_PAValid : in BOOLEAN ; 
			F_PLB_SAValid : in BOOLEAN ; 
			F_PLB_rdPrim : in BOOLEAN ; 
			F_PLB_wrPrim : in BOOLEAN ; 
			F_PLB_masterID : in UNSIGNED ( 1 downto 0 ) ; 
			F_PLB_abort : in BOOLEAN ; 
			F_PLB_busLock : in BOOLEAN ; 
			F_PLB_RNW : in BOOLEAN ; 
			F_PLB_BE : in UNSIGNED ( 3 downto 0 ) ; 
			F_PLB_MSize : in UNSIGNED ( 1 downto 0 ) ; 
			F_PLB_size : in UNSIGNED ( 3 downto 0 ) ; 
			F_PLB_type : in UNSIGNED ( 2 downto 0 ) ; 
			F_PLB_lockErr : in BOOLEAN ; 
			F_PLB_wrDBus : in UNSIGNED ( 31 downto 0 ) ; 
			F_PLB_wrBurst : in BOOLEAN ; 
			F_PLB_rdBurst : in BOOLEAN ; 
			F_PLB_wrPendReq : in BOOLEAN ; 
			F_PLB_rdPendReq : in BOOLEAN ; 
			F_PLB_wrPendPri : in UNSIGNED ( 1 downto 0 ) ; 
			F_PLB_rdPendPri : in UNSIGNED ( 1 downto 0 ) ; 
			F_PLB_reqPri : in UNSIGNED ( 1 downto 0 ) ; 
			F_PLB_TAttribute : in UNSIGNED ( 15 downto 0 ) ; 
			
			F_Sl_addrAck : out BOOLEAN ; 
			F_Sl_SSize : out UNSIGNED ( 1 downto 0 ) ; 
			F_Sl_wait : out BOOLEAN ; 
			F_Sl_rearbitrate : out BOOLEAN ; 
			F_Sl_wrDAck : out BOOLEAN ; 
			F_Sl_wrComp : out BOOLEAN ; 
			F_Sl_wrBTerm : out BOOLEAN ; 
			F_Sl_rdDBus : out UNSIGNED ( 31 downto 0 ) ; 
			F_Sl_rdWdAddr : out UNSIGNED ( 3 downto 0 ) ; 
			F_Sl_rdDAck : out BOOLEAN ; 
			F_Sl_rdComp : out BOOLEAN ; 
			F_Sl_rdBTerm : out BOOLEAN ; 
			F_Sl_MBusy : out UNSIGNED ( 3 downto 0 ) ; 
			F_Sl_MWrErr : out UNSIGNED ( 3 downto 0 ) ; 
			F_Sl_MRdErr : out UNSIGNED ( 3 downto 0 ) ; 
			F_Sl_MIRQ : out UNSIGNED ( 3 downto 0 ) ; 
			
			F_LEDs : out UNSIGNED ( 7 downto 0 ) 
		);
	end component;
	
	signal s_F_SPLB_Clk : BOOLEAN ; 
	signal s_F_SPLB_Rst : BOOLEAN ; 
	signal s_F_PLB_ABus : UNSIGNED ( 31 downto 0 ) ; 
	signal s_F_PLB_UABus : UNSIGNED ( 31 downto 0 ) ; 
	signal s_F_PLB_PAValid : BOOLEAN ; 
	signal s_F_PLB_SAValid : BOOLEAN ; 
	signal s_F_PLB_rdPrim : BOOLEAN ; 
	signal s_F_PLB_wrPrim : BOOLEAN ; 
	signal s_F_PLB_masterID : UNSIGNED ( 1 downto 0 ) ; 
	signal s_F_PLB_abort : BOOLEAN ; 
	signal s_F_PLB_busLock : BOOLEAN ; 
	signal s_F_PLB_RNW : BOOLEAN ; 
	signal s_F_PLB_BE : UNSIGNED ( 3 downto 0 ) ; 
	signal s_F_PLB_MSize : UNSIGNED ( 1 downto 0 ) ; 
	signal s_F_PLB_size : UNSIGNED ( 3 downto 0 ) ; 
	signal s_F_PLB_type : UNSIGNED ( 2 downto 0 ) ; 
	signal s_F_PLB_lockErr : BOOLEAN ; 
	signal s_F_PLB_wrDBus : UNSIGNED (31 downto 0 ) ; 
	signal s_F_PLB_wrBurst : BOOLEAN ; 
	signal s_F_PLB_rdBurst : BOOLEAN ; 
	signal s_F_PLB_wrPendReq : BOOLEAN ; 
	signal s_F_PLB_rdPendReq : BOOLEAN ; 
	signal s_F_PLB_wrPendPri : UNSIGNED ( 1 downto 0 ) ; 
	signal s_F_PLB_rdPendPri : UNSIGNED ( 1 downto 0 ) ; 
	signal s_F_PLB_reqPri : UNSIGNED ( 1 downto 0 ) ; 
	signal s_F_PLB_TAttribute : UNSIGNED ( 15 downto 0 ) ; 
	signal s_F_Sl_addrAck : BOOLEAN ; 
	signal s_F_Sl_SSize : UNSIGNED ( 1 downto 0 ) ; 
	signal s_F_Sl_wait : BOOLEAN ; 
	signal s_F_Sl_rearbitrate : BOOLEAN ; 
	signal s_F_Sl_wrDAck : BOOLEAN ; 
	signal s_F_Sl_wrComp : BOOLEAN ; 
	signal s_F_Sl_wrBTerm : BOOLEAN ; 
	signal s_F_Sl_rdDBus : UNSIGNED ( 31 downto 0 ) ; 
	signal s_F_Sl_rdWdAddr : UNSIGNED ( 3 downto 0 ) ; 
	signal s_F_Sl_rdDAck : BOOLEAN ; 
	signal s_F_Sl_rdComp : BOOLEAN ; 
	signal s_F_Sl_rdBTerm : BOOLEAN ; 
	signal s_F_Sl_MBusy : UNSIGNED ( 3 downto 0 ) ; 
	signal s_F_Sl_MWrErr : UNSIGNED ( 3 downto 0 ) ; 
	signal s_F_Sl_MRdErr : UNSIGNED ( 3 downto 0 ) ; 
	signal s_F_Sl_MIRQ : UNSIGNED ( 3 downto 0 ) ; 
	
	signal s_F_LEDs : UNSIGNED ( 7 downto 0 ) ;
begin
	FIPCB_0 : FIPCB
	port map(
		F_SPLB_Clk => s_F_SPLB_Clk,
		F_SPLB_Rst => s_F_SPLB_Rst,
		F_PLB_ABus => s_F_PLB_ABus,
		F_PLB_UABus => s_F_PLB_UABus,
		F_PLB_PAValid => s_F_PLB_PAValid,
		F_PLB_SAValid => s_F_PLB_SAValid,
		F_PLB_rdPrim => s_F_PLB_rdPrim,
		F_PLB_wrPrim => s_F_PLB_wrPrim,
		F_PLB_masterID => s_F_PLB_masterID,
		F_PLB_abort => s_F_PLB_abort,
		F_PLB_busLock => s_F_PLB_busLock,
		F_PLB_RNW => s_F_PLB_RNW,
		F_PLB_BE => s_F_PLB_BE,
		F_PLB_MSize => s_F_PLB_MSize,
		F_PLB_size => s_F_PLB_size,
		F_PLB_type => s_F_PLB_type,
		F_PLB_lockErr => s_F_PLB_lockErr,
		F_PLB_wrDBus => s_F_PLB_wrDBus,
		F_PLB_wrBurst => s_F_PLB_wrBurst,
		F_PLB_rdBurst => s_F_PLB_rdBurst,
		F_PLB_wrPendReq => s_F_PLB_wrPendReq,
		F_PLB_rdPendReq => s_F_PLB_rdPendReq,
		F_PLB_wrPendPri => s_F_PLB_wrPendPri,
		F_PLB_rdPendPri => s_F_PLB_rdPendPri,
		F_PLB_reqPri => s_F_PLB_reqPri,
		F_PLB_TAttribute => s_F_PLB_TAttribute,
		F_Sl_addrAck => s_F_Sl_addrAck,
		F_Sl_SSize => s_F_Sl_SSize,
		F_Sl_wait => s_F_Sl_wait,
		F_Sl_rearbitrate => s_F_Sl_rearbitrate,
		F_Sl_wrDAck => s_F_Sl_wrDAck,
		F_Sl_wrComp => s_F_Sl_wrComp,
		F_Sl_wrBTerm => s_F_Sl_wrBTerm,
		F_Sl_rdDBus => s_F_Sl_rdDBus,
		F_Sl_rdWdAddr => s_F_Sl_rdWdAddr,
		F_Sl_rdDAck => s_F_Sl_rdDAck,
		F_Sl_rdComp => s_F_Sl_rdComp,
		F_Sl_rdBTerm => s_F_Sl_rdBTerm,
		F_Sl_MBusy => s_F_Sl_MBusy,
		F_Sl_MWrErr => s_F_Sl_MWrErr,
		F_Sl_MRdErr => s_F_Sl_MRdErr,
		F_Sl_MIRQ => s_F_Sl_MIRQ,
		
		F_LEDs => s_F_LEDs
	);
	
	s_F_SPLB_Clk <= std_logic_to_bool(SPLB_Clk);
	s_F_SPLB_Rst <= std_logic_to_bool(SPLB_Rst);
	s_F_PLB_ABus <= UNSIGNED(SIGNED(PLB_ABus));
	s_F_PLB_UABus <= UNSIGNED(SIGNED(PLB_UABus));
	s_F_PLB_PAValid <= std_logic_to_bool(PLB_PAValid);
	s_F_PLB_SAValid <= std_logic_to_bool(PLB_SAValid);
	s_F_PLB_rdPrim <= std_logic_to_bool(PLB_rdPrim);
	s_F_PLB_wrPrim <= std_logic_to_bool(PLB_wrPrim);
	s_F_PLB_masterID <= UNSIGNED(SIGNED(PLB_masterID));
	s_F_PLB_abort <= std_logic_to_bool(PLB_abort);
	s_F_PLB_busLock <= std_logic_to_bool(PLB_busLock);
	s_F_PLB_RNW <= std_logic_to_bool(PLB_RNW);
	s_F_PLB_BE <= UNSIGNED(SIGNED(PLB_BE));
	s_F_PLB_MSize <= UNSIGNED(SIGNED(PLB_MSize));
	s_F_PLB_size <= UNSIGNED(SIGNED(PLB_size));
	s_F_PLB_type <= UNSIGNED(SIGNED(PLB_type));	
	s_F_PLB_lockErr <= std_logic_to_bool(PLB_lockErr);
	s_F_PLB_wrDBus <= UNSIGNED(SIGNED(PLB_wrDBus));	
	s_F_PLB_wrBurst <= std_logic_to_bool(PLB_wrBurst);
	s_F_PLB_rdBurst <= std_logic_to_bool(PLB_rdBurst);
	s_F_PLB_wrPendReq <= std_logic_to_bool(PLB_wrPendReq);
	s_F_PLB_rdPendReq <= std_logic_to_bool(PLB_rdPendReq);
	s_F_PLB_wrPendPri <= UNSIGNED(SIGNED(PLB_wrPendPri));
	s_F_PLB_rdPendPri <= UNSIGNED(SIGNED(PLB_rdPendPri));
	s_F_PLB_reqPri <= UNSIGNED(SIGNED(PLB_reqPri));
	s_F_PLB_TAttribute <= UNSIGNED(SIGNED(PLB_TAttribute));
	
	Sl_addrAck <= bool_to_std_logic(s_F_Sl_addrAck);
	Sl_SSize <= std_logic_vector(s_F_Sl_SSize);
	Sl_wait <= bool_to_std_logic(s_F_Sl_wait);
	Sl_rearbitrate <= bool_to_std_logic(s_F_Sl_rearbitrate);
	Sl_wrDAck <= bool_to_std_logic(s_F_Sl_wrDAck);
	Sl_wrComp <= bool_to_std_logic(s_F_Sl_wrComp);
	Sl_wrBTerm <= bool_to_std_logic(s_F_Sl_wrBTerm);
	Sl_rdDBus <= std_logic_vector(s_F_Sl_rdDBus);
	Sl_rdWdAddr <= std_logic_vector(s_F_Sl_rdWdAddr);
	Sl_rdDAck <= bool_to_std_logic(s_F_Sl_rdDAck);
	Sl_rdComp <= bool_to_std_logic(s_F_Sl_rdComp);
	Sl_rdBTerm <= bool_to_std_logic(s_F_Sl_rdBTerm);
	Sl_MBusy <= std_logic_vector(s_F_Sl_MBusy);
	Sl_MWrErr <= std_logic_vector(s_F_Sl_MWrErr);
	Sl_MRdErr <= std_logic_vector(s_F_Sl_MRdErr);
	Sl_MIRQ <= std_logic_vector(s_F_Sl_MIRQ);
		
	LEDs <= std_logic_vector(s_F_LEDs);
end IMP;
