library IEEE; 
use IEEE.STD_LOGIC_1164.all; 
use IEEE.NUMERIC_STD.all; 

package OSSS_PKG is 

function FOSSY_TO_STD_LOGIC_VECTOR(ARG: BOOLEAN) return STD_LOGIC_VECTOR;
 


function FOSSY_GT_U8_S32 ( lhs : in UNSIGNED ( 7 downto 0 ) ; rhs : in SIGNED ( 31 downto 0 ) ) return BOOLEAN ; 
function FOSSY_GT_U32_S32 ( lhs : in UNSIGNED ( 31 downto 0 ) ; rhs : in SIGNED ( 31 downto 0 ) ) return BOOLEAN ; 
function FOSSY_EQ_U32_S32 ( lhs : in UNSIGNED ( 31 downto 0 ) ; rhs : in SIGNED ( 31 downto 0 ) ) return BOOLEAN ; 
function FOSSY_RANGE_U8_1 ( obj : in UNSIGNED ( 7 downto 0 ) ; l : in INTEGER ) return STD_LOGIC_VECTOR ; 
function FOSSY_RANGE_S32_1 ( obj : in SIGNED ( 31 downto 0 ) ; l : in INTEGER ) return STD_LOGIC_VECTOR ; 
function FOSSY_EQ_U32_U32 ( lhs : in UNSIGNED ( 31 downto 0 ) ; rhs : in UNSIGNED ( 31 downto 0 ) ) return BOOLEAN ; 
function FOSSY_RANGE_U8_4 ( obj : in UNSIGNED ( 7 downto 0 ) ; l : in INTEGER ) return STD_LOGIC_VECTOR ; 
function FOSSY_SHL_U4_U2_4 ( lhs : in UNSIGNED ( 3 downto 0 ) ; rhs : in UNSIGNED ( 1 downto 0 ) ) return UNSIGNED ; 
function FOSSY_EQ_V16_U64 ( lhs : in STD_LOGIC_VECTOR ( 15  downto 0 ) ; rhs : in UNSIGNED ( 63 downto 0 ) ) return BOOLEAN ; 
function FOSSY_RANGE_U32_16 ( obj : in UNSIGNED ( 31 downto 0 ) ; l : in INTEGER ) return STD_LOGIC_VECTOR ; 
function FOSSY_RANGE_S32_8 ( obj : in SIGNED ( 31 downto 0 ) ; l : in INTEGER ) return STD_LOGIC_VECTOR ; 
function FOSSY_RANGE_S32_4 ( obj : in SIGNED ( 31 downto 0 ) ; l : in INTEGER ) return STD_LOGIC_VECTOR ; 
function FOSSY_RANGE_S32_2 ( obj : in SIGNED ( 31 downto 0 ) ; l : in INTEGER ) return STD_LOGIC_VECTOR ; 
function FOSSY_EQ_B1_B1 ( lhs : in BOOLEAN ; rhs : in BOOLEAN ) return BOOLEAN ; 


end package OSSS_PKG ; 

package body OSSS_PKG is 
function FOSSY_GT_U8_S32 ( lhs : in UNSIGNED ( 7 downto 0 ) ; rhs : in SIGNED ( 31 downto 0 ) ) return BOOLEAN is 
  variable extended_lhs : SIGNED(31 downto 0);
  variable extended_rhs : SIGNED(31 downto 0);
  variable result : BOOLEAN;
begin
  extended_lhs := "00000000000000000000000000000000";
  extended_rhs := "00000000000000000000000000000000";
  result := FALSE;
  extended_lhs(7 downto 0) := SIGNED(lhs(7 downto 0));
  extended_rhs := (others => rhs(31));
  extended_rhs(30 downto 0) := rhs(30 downto 0);
  result := extended_lhs > extended_rhs;
  return result;
end;
 
function FOSSY_GT_U32_S32 ( lhs : in UNSIGNED ( 31 downto 0 ) ; rhs : in SIGNED ( 31 downto 0 ) ) return BOOLEAN is 
  variable extended_lhs : SIGNED(32 downto 0);
  variable extended_rhs : SIGNED(32 downto 0);
  variable result : BOOLEAN;
begin
  extended_lhs := "000000000000000000000000000000000";
  extended_rhs := "000000000000000000000000000000000";
  result := FALSE;
  extended_lhs(31 downto 0) := SIGNED(lhs(31 downto 0));
  extended_rhs := (others => rhs(31));
  extended_rhs(30 downto 0) := rhs(30 downto 0);
  result := extended_lhs > extended_rhs;
  return result;
end;
 
function FOSSY_EQ_U32_S32 ( lhs : in UNSIGNED ( 31 downto 0 ) ; rhs : in SIGNED ( 31 downto 0 ) ) return BOOLEAN is 
  variable extended_lhs : SIGNED(32 downto 0);
  variable extended_rhs : SIGNED(32 downto 0);
  variable result : BOOLEAN;
begin
  extended_lhs := "000000000000000000000000000000000";
  extended_rhs := "000000000000000000000000000000000";
  result := FALSE;
  extended_lhs(31 downto 0) := SIGNED(lhs(31 downto 0));
  extended_rhs := (others => rhs(31));
  extended_rhs(30 downto 0) := rhs(30 downto 0);
  result := extended_lhs = extended_rhs;
  return result;
end;
 
function FOSSY_RANGE_U8_1 ( obj : in UNSIGNED ( 7 downto 0 ) ; l : in INTEGER ) return STD_LOGIC_VECTOR is 
  variable result : STD_LOGIC_VECTOR(0 downto 0);
begin
  case l is
    when 0 => 
      result := STD_LOGIC_VECTOR(obj(0 downto 0));
    when 1 => 
      result := STD_LOGIC_VECTOR(obj(1 downto 1));
    when 2 => 
      result := STD_LOGIC_VECTOR(obj(2 downto 2));
    when 3 => 
      result := STD_LOGIC_VECTOR(obj(3 downto 3));
    when 4 => 
      result := STD_LOGIC_VECTOR(obj(4 downto 4));
    when 5 => 
      result := STD_LOGIC_VECTOR(obj(5 downto 5));
    when 6 => 
      result := STD_LOGIC_VECTOR(obj(6 downto 6));
    when 7 => 
      result := STD_LOGIC_VECTOR(obj(7 downto 7));
     when others => null;
  end case;
  return result;
end;
 
function FOSSY_RANGE_S32_1 ( obj : in SIGNED ( 31 downto 0 ) ; l : in INTEGER ) return STD_LOGIC_VECTOR is 
  variable result : STD_LOGIC_VECTOR(0 downto 0);
begin
  case l is
    when 0 => 
      result := STD_LOGIC_VECTOR(obj(0 downto 0));
    when 1 => 
      result := STD_LOGIC_VECTOR(obj(1 downto 1));
    when 2 => 
      result := STD_LOGIC_VECTOR(obj(2 downto 2));
    when 3 => 
      result := STD_LOGIC_VECTOR(obj(3 downto 3));
    when 4 => 
      result := STD_LOGIC_VECTOR(obj(4 downto 4));
    when 5 => 
      result := STD_LOGIC_VECTOR(obj(5 downto 5));
    when 6 => 
      result := STD_LOGIC_VECTOR(obj(6 downto 6));
    when 7 => 
      result := STD_LOGIC_VECTOR(obj(7 downto 7));
    when 8 => 
      result := STD_LOGIC_VECTOR(obj(8 downto 8));
    when 9 => 
      result := STD_LOGIC_VECTOR(obj(9 downto 9));
    when 10 => 
      result := STD_LOGIC_VECTOR(obj(10 downto 10));
    when 11 => 
      result := STD_LOGIC_VECTOR(obj(11 downto 11));
    when 12 => 
      result := STD_LOGIC_VECTOR(obj(12 downto 12));
    when 13 => 
      result := STD_LOGIC_VECTOR(obj(13 downto 13));
    when 14 => 
      result := STD_LOGIC_VECTOR(obj(14 downto 14));
    when 15 => 
      result := STD_LOGIC_VECTOR(obj(15 downto 15));
    when 16 => 
      result := STD_LOGIC_VECTOR(obj(16 downto 16));
    when 17 => 
      result := STD_LOGIC_VECTOR(obj(17 downto 17));
    when 18 => 
      result := STD_LOGIC_VECTOR(obj(18 downto 18));
    when 19 => 
      result := STD_LOGIC_VECTOR(obj(19 downto 19));
    when 20 => 
      result := STD_LOGIC_VECTOR(obj(20 downto 20));
    when 21 => 
      result := STD_LOGIC_VECTOR(obj(21 downto 21));
    when 22 => 
      result := STD_LOGIC_VECTOR(obj(22 downto 22));
    when 23 => 
      result := STD_LOGIC_VECTOR(obj(23 downto 23));
    when 24 => 
      result := STD_LOGIC_VECTOR(obj(24 downto 24));
    when 25 => 
      result := STD_LOGIC_VECTOR(obj(25 downto 25));
    when 26 => 
      result := STD_LOGIC_VECTOR(obj(26 downto 26));
    when 27 => 
      result := STD_LOGIC_VECTOR(obj(27 downto 27));
    when 28 => 
      result := STD_LOGIC_VECTOR(obj(28 downto 28));
    when 29 => 
      result := STD_LOGIC_VECTOR(obj(29 downto 29));
    when 30 => 
      result := STD_LOGIC_VECTOR(obj(30 downto 30));
    when 31 => 
      result := STD_LOGIC_VECTOR(obj(31 downto 31));
     when others => null;
  end case;
  return result;
end;
 
function FOSSY_EQ_U32_U32 ( lhs : in UNSIGNED ( 31 downto 0 ) ; rhs : in UNSIGNED ( 31 downto 0 ) ) return BOOLEAN is 
  variable extended_lhs : UNSIGNED(31 downto 0);
  variable extended_rhs : UNSIGNED(31 downto 0);
  variable result : BOOLEAN;
begin
  extended_lhs := "00000000000000000000000000000000";
  extended_rhs := "00000000000000000000000000000000";
  result := FALSE;
  extended_lhs(31 downto 0) := lhs(31 downto 0);
  extended_rhs(31 downto 0) := rhs(31 downto 0);
  result := extended_lhs = extended_rhs;
  return result;
end;
 
function FOSSY_RANGE_U8_4 ( obj : in UNSIGNED ( 7 downto 0 ) ; l : in INTEGER ) return STD_LOGIC_VECTOR is 
  variable result : STD_LOGIC_VECTOR(3 downto 0);
begin
  case l is
    when 3 => 
      result := STD_LOGIC_VECTOR(obj(3 downto 0));
    when 4 => 
      result := STD_LOGIC_VECTOR(obj(4 downto 1));
    when 5 => 
      result := STD_LOGIC_VECTOR(obj(5 downto 2));
    when 6 => 
      result := STD_LOGIC_VECTOR(obj(6 downto 3));
    when 7 => 
      result := STD_LOGIC_VECTOR(obj(7 downto 4));
     when others => null;
  end case;
  return result;
end;
 
function FOSSY_SHL_U4_U2_4 ( lhs : in UNSIGNED ( 3 downto 0 ) ; rhs : in UNSIGNED ( 1 downto 0 ) ) return UNSIGNED is 
  variable extended_lhs : UNSIGNED(3 downto 0);
  variable result : UNSIGNED(3 downto 0);
begin
  extended_lhs := "0000";
  result := "0000";
  extended_lhs(3 downto 0) := lhs(3 downto 0);
  result := SHIFT_LEFT(extended_lhs, TO_INTEGER(rhs));
  return result;
end;
 
function FOSSY_EQ_V16_U64 ( lhs : in STD_LOGIC_VECTOR ( 15  downto 0 ) ; rhs : in UNSIGNED ( 63 downto 0 ) ) return BOOLEAN is 
  variable extended_lhs : STD_LOGIC_VECTOR(63 downto 0);
  variable extended_rhs : UNSIGNED(63 downto 0);
  variable result : BOOLEAN;
begin
  extended_lhs := "0000000000000000000000000000000000000000000000000000000000000000";
  extended_rhs := "0000000000000000000000000000000000000000000000000000000000000000";
  result := FALSE;
  extended_lhs(15 downto 0) := lhs(15 downto 0);
  extended_rhs(63 downto 0) := rhs(63 downto 0);
  result := UNSIGNED(extended_lhs) = extended_rhs;
  return result;
end;
 
function FOSSY_RANGE_U32_16 ( obj : in UNSIGNED ( 31 downto 0 ) ; l : in INTEGER ) return STD_LOGIC_VECTOR is 
  variable result : STD_LOGIC_VECTOR(15 downto 0);
begin
  case l is
    when 15 => 
      result := STD_LOGIC_VECTOR(obj(15 downto 0));
    when 16 => 
      result := STD_LOGIC_VECTOR(obj(16 downto 1));
    when 17 => 
      result := STD_LOGIC_VECTOR(obj(17 downto 2));
    when 18 => 
      result := STD_LOGIC_VECTOR(obj(18 downto 3));
    when 19 => 
      result := STD_LOGIC_VECTOR(obj(19 downto 4));
    when 20 => 
      result := STD_LOGIC_VECTOR(obj(20 downto 5));
    when 21 => 
      result := STD_LOGIC_VECTOR(obj(21 downto 6));
    when 22 => 
      result := STD_LOGIC_VECTOR(obj(22 downto 7));
    when 23 => 
      result := STD_LOGIC_VECTOR(obj(23 downto 8));
    when 24 => 
      result := STD_LOGIC_VECTOR(obj(24 downto 9));
    when 25 => 
      result := STD_LOGIC_VECTOR(obj(25 downto 10));
    when 26 => 
      result := STD_LOGIC_VECTOR(obj(26 downto 11));
    when 27 => 
      result := STD_LOGIC_VECTOR(obj(27 downto 12));
    when 28 => 
      result := STD_LOGIC_VECTOR(obj(28 downto 13));
    when 29 => 
      result := STD_LOGIC_VECTOR(obj(29 downto 14));
    when 30 => 
      result := STD_LOGIC_VECTOR(obj(30 downto 15));
    when 31 => 
      result := STD_LOGIC_VECTOR(obj(31 downto 16));
     when others => null;
  end case;
  return result;
end;
 
function FOSSY_RANGE_S32_8 ( obj : in SIGNED ( 31 downto 0 ) ; l : in INTEGER ) return STD_LOGIC_VECTOR is 
  variable result : STD_LOGIC_VECTOR(7 downto 0);
begin
  case l is
    when 7 => 
      result := STD_LOGIC_VECTOR(obj(7 downto 0));
    when 8 => 
      result := STD_LOGIC_VECTOR(obj(8 downto 1));
    when 9 => 
      result := STD_LOGIC_VECTOR(obj(9 downto 2));
    when 10 => 
      result := STD_LOGIC_VECTOR(obj(10 downto 3));
    when 11 => 
      result := STD_LOGIC_VECTOR(obj(11 downto 4));
    when 12 => 
      result := STD_LOGIC_VECTOR(obj(12 downto 5));
    when 13 => 
      result := STD_LOGIC_VECTOR(obj(13 downto 6));
    when 14 => 
      result := STD_LOGIC_VECTOR(obj(14 downto 7));
    when 15 => 
      result := STD_LOGIC_VECTOR(obj(15 downto 8));
    when 16 => 
      result := STD_LOGIC_VECTOR(obj(16 downto 9));
    when 17 => 
      result := STD_LOGIC_VECTOR(obj(17 downto 10));
    when 18 => 
      result := STD_LOGIC_VECTOR(obj(18 downto 11));
    when 19 => 
      result := STD_LOGIC_VECTOR(obj(19 downto 12));
    when 20 => 
      result := STD_LOGIC_VECTOR(obj(20 downto 13));
    when 21 => 
      result := STD_LOGIC_VECTOR(obj(21 downto 14));
    when 22 => 
      result := STD_LOGIC_VECTOR(obj(22 downto 15));
    when 23 => 
      result := STD_LOGIC_VECTOR(obj(23 downto 16));
    when 24 => 
      result := STD_LOGIC_VECTOR(obj(24 downto 17));
    when 25 => 
      result := STD_LOGIC_VECTOR(obj(25 downto 18));
    when 26 => 
      result := STD_LOGIC_VECTOR(obj(26 downto 19));
    when 27 => 
      result := STD_LOGIC_VECTOR(obj(27 downto 20));
    when 28 => 
      result := STD_LOGIC_VECTOR(obj(28 downto 21));
    when 29 => 
      result := STD_LOGIC_VECTOR(obj(29 downto 22));
    when 30 => 
      result := STD_LOGIC_VECTOR(obj(30 downto 23));
    when 31 => 
      result := STD_LOGIC_VECTOR(obj(31 downto 24));
     when others => null;
  end case;
  return result;
end;
 
function FOSSY_RANGE_S32_4 ( obj : in SIGNED ( 31 downto 0 ) ; l : in INTEGER ) return STD_LOGIC_VECTOR is 
  variable result : STD_LOGIC_VECTOR(3 downto 0);
begin
  case l is
    when 3 => 
      result := STD_LOGIC_VECTOR(obj(3 downto 0));
    when 4 => 
      result := STD_LOGIC_VECTOR(obj(4 downto 1));
    when 5 => 
      result := STD_LOGIC_VECTOR(obj(5 downto 2));
    when 6 => 
      result := STD_LOGIC_VECTOR(obj(6 downto 3));
    when 7 => 
      result := STD_LOGIC_VECTOR(obj(7 downto 4));
    when 8 => 
      result := STD_LOGIC_VECTOR(obj(8 downto 5));
    when 9 => 
      result := STD_LOGIC_VECTOR(obj(9 downto 6));
    when 10 => 
      result := STD_LOGIC_VECTOR(obj(10 downto 7));
    when 11 => 
      result := STD_LOGIC_VECTOR(obj(11 downto 8));
    when 12 => 
      result := STD_LOGIC_VECTOR(obj(12 downto 9));
    when 13 => 
      result := STD_LOGIC_VECTOR(obj(13 downto 10));
    when 14 => 
      result := STD_LOGIC_VECTOR(obj(14 downto 11));
    when 15 => 
      result := STD_LOGIC_VECTOR(obj(15 downto 12));
    when 16 => 
      result := STD_LOGIC_VECTOR(obj(16 downto 13));
    when 17 => 
      result := STD_LOGIC_VECTOR(obj(17 downto 14));
    when 18 => 
      result := STD_LOGIC_VECTOR(obj(18 downto 15));
    when 19 => 
      result := STD_LOGIC_VECTOR(obj(19 downto 16));
    when 20 => 
      result := STD_LOGIC_VECTOR(obj(20 downto 17));
    when 21 => 
      result := STD_LOGIC_VECTOR(obj(21 downto 18));
    when 22 => 
      result := STD_LOGIC_VECTOR(obj(22 downto 19));
    when 23 => 
      result := STD_LOGIC_VECTOR(obj(23 downto 20));
    when 24 => 
      result := STD_LOGIC_VECTOR(obj(24 downto 21));
    when 25 => 
      result := STD_LOGIC_VECTOR(obj(25 downto 22));
    when 26 => 
      result := STD_LOGIC_VECTOR(obj(26 downto 23));
    when 27 => 
      result := STD_LOGIC_VECTOR(obj(27 downto 24));
    when 28 => 
      result := STD_LOGIC_VECTOR(obj(28 downto 25));
    when 29 => 
      result := STD_LOGIC_VECTOR(obj(29 downto 26));
    when 30 => 
      result := STD_LOGIC_VECTOR(obj(30 downto 27));
    when 31 => 
      result := STD_LOGIC_VECTOR(obj(31 downto 28));
     when others => null;
  end case;
  return result;
end;
 
function FOSSY_RANGE_S32_2 ( obj : in SIGNED ( 31 downto 0 ) ; l : in INTEGER ) return STD_LOGIC_VECTOR is 
  variable result : STD_LOGIC_VECTOR(1 downto 0);
begin
  case l is
    when 1 => 
      result := STD_LOGIC_VECTOR(obj(1 downto 0));
    when 2 => 
      result := STD_LOGIC_VECTOR(obj(2 downto 1));
    when 3 => 
      result := STD_LOGIC_VECTOR(obj(3 downto 2));
    when 4 => 
      result := STD_LOGIC_VECTOR(obj(4 downto 3));
    when 5 => 
      result := STD_LOGIC_VECTOR(obj(5 downto 4));
    when 6 => 
      result := STD_LOGIC_VECTOR(obj(6 downto 5));
    when 7 => 
      result := STD_LOGIC_VECTOR(obj(7 downto 6));
    when 8 => 
      result := STD_LOGIC_VECTOR(obj(8 downto 7));
    when 9 => 
      result := STD_LOGIC_VECTOR(obj(9 downto 8));
    when 10 => 
      result := STD_LOGIC_VECTOR(obj(10 downto 9));
    when 11 => 
      result := STD_LOGIC_VECTOR(obj(11 downto 10));
    when 12 => 
      result := STD_LOGIC_VECTOR(obj(12 downto 11));
    when 13 => 
      result := STD_LOGIC_VECTOR(obj(13 downto 12));
    when 14 => 
      result := STD_LOGIC_VECTOR(obj(14 downto 13));
    when 15 => 
      result := STD_LOGIC_VECTOR(obj(15 downto 14));
    when 16 => 
      result := STD_LOGIC_VECTOR(obj(16 downto 15));
    when 17 => 
      result := STD_LOGIC_VECTOR(obj(17 downto 16));
    when 18 => 
      result := STD_LOGIC_VECTOR(obj(18 downto 17));
    when 19 => 
      result := STD_LOGIC_VECTOR(obj(19 downto 18));
    when 20 => 
      result := STD_LOGIC_VECTOR(obj(20 downto 19));
    when 21 => 
      result := STD_LOGIC_VECTOR(obj(21 downto 20));
    when 22 => 
      result := STD_LOGIC_VECTOR(obj(22 downto 21));
    when 23 => 
      result := STD_LOGIC_VECTOR(obj(23 downto 22));
    when 24 => 
      result := STD_LOGIC_VECTOR(obj(24 downto 23));
    when 25 => 
      result := STD_LOGIC_VECTOR(obj(25 downto 24));
    when 26 => 
      result := STD_LOGIC_VECTOR(obj(26 downto 25));
    when 27 => 
      result := STD_LOGIC_VECTOR(obj(27 downto 26));
    when 28 => 
      result := STD_LOGIC_VECTOR(obj(28 downto 27));
    when 29 => 
      result := STD_LOGIC_VECTOR(obj(29 downto 28));
    when 30 => 
      result := STD_LOGIC_VECTOR(obj(30 downto 29));
    when 31 => 
      result := STD_LOGIC_VECTOR(obj(31 downto 30));
     when others => null;
  end case;
  return result;
end;
 
function FOSSY_EQ_B1_B1 ( lhs : in BOOLEAN ; rhs : in BOOLEAN ) return BOOLEAN is 
begin
  return lhs = rhs;
end;
 
function FOSSY_TO_STD_LOGIC_VECTOR (ARG: BOOLEAN) return STD_LOGIC_VECTOR is 
  variable result : STD_LOGIC_VECTOR(0 downto 0); 
begin
  if arg
  then
    result := "1";
  else
    result := "0";
  end if;
  return result;
end; 



 
end package body OSSS_PKG ; 
library IEEE; 
use IEEE.STD_LOGIC_1164.all; 
use IEEE.NUMERIC_STD.all; 
use WORK.OSSS_PKG.all; 

entity FIPCB is 
  port ( 
    F_SPLB_Clk : in BOOLEAN ; 
    F_SPLB_Rst : in BOOLEAN ; 
    F_PLB_ABus : in UNSIGNED ( 31 downto 0 ) ; 
    F_PLB_UABus : in UNSIGNED ( 31 downto 0 ) ; 
    F_PLB_PAValid : in BOOLEAN ; 
    F_PLB_SAValid : in BOOLEAN ; 
    F_PLB_rdPrim : in BOOLEAN ; 
    F_PLB_wrPrim : in BOOLEAN ; 
    F_PLB_masterID : in UNSIGNED ( 1 downto 0 ) ; 
    F_PLB_abort : in BOOLEAN ; 
    F_PLB_busLock : in BOOLEAN ; 
    F_PLB_RNW : in BOOLEAN ; 
    F_PLB_BE : in UNSIGNED ( 3 downto 0 ) ; 
    F_PLB_MSize : in UNSIGNED ( 1 downto 0 ) ; 
    F_PLB_size : in UNSIGNED ( 3 downto 0 ) ; 
    F_PLB_type : in UNSIGNED ( 2 downto 0 ) ; 
    F_PLB_lockErr : in BOOLEAN ; 
    F_PLB_wrDBus : in UNSIGNED ( 31 downto 0 ) ; 
    F_PLB_wrBurst : in BOOLEAN ; 
    F_PLB_rdBurst : in BOOLEAN ; 
    F_PLB_wrPendReq : in BOOLEAN ; 
    F_PLB_rdPendReq : in BOOLEAN ; 
    F_PLB_wrPendPri : in UNSIGNED ( 1 downto 0 ) ; 
    F_PLB_rdPendPri : in UNSIGNED ( 1 downto 0 ) ; 
    F_PLB_reqPri : in UNSIGNED ( 1 downto 0 ) ; 
    F_PLB_TAttribute : in UNSIGNED ( 15 downto 0 ) ; 
    F_Sl_addrAck : out BOOLEAN ; 
    F_Sl_SSize : out UNSIGNED ( 1 downto 0 ) ; 
    F_Sl_wait : out BOOLEAN ; 
    F_Sl_rearbitrate : out BOOLEAN ; 
    F_Sl_wrDAck : out BOOLEAN ; 
    F_Sl_wrComp : out BOOLEAN ; 
    F_Sl_wrBTerm : out BOOLEAN ; 
    F_Sl_rdDBus : out UNSIGNED ( 31 downto 0 ) ; 
    F_Sl_rdWdAddr : out UNSIGNED ( 3 downto 0 ) ; 
    F_Sl_rdDAck : out BOOLEAN ; 
    F_Sl_rdComp : out BOOLEAN ; 
    F_Sl_rdBTerm : out BOOLEAN ; 
    F_Sl_MBusy : out UNSIGNED ( 3 downto 0 ) ; 
    F_Sl_MWrErr : out UNSIGNED ( 3 downto 0 ) ; 
    F_Sl_MRdErr : out UNSIGNED ( 3 downto 0 ) ; 
    F_Sl_MIRQ : out UNSIGNED ( 3 downto 0 ) ; 
    F_LEDs : out UNSIGNED ( 7 downto 0 ) 
  ) ; 
end entity FIPCB ; 

architecture BEHAVIOUR of FIPCB is 
  signal SPLB_state : UNSIGNED ( 2 downto 0 ) ; 
  signal SPLB_Register0 : UNSIGNED ( 31 downto 0 ) ; 
  signal SPLB_Register1 : UNSIGNED ( 31 downto 0 ) ; 
  signal SPLB_Register2 : UNSIGNED ( 31 downto 0 ) ; 
  signal SPLB_Register3 : UNSIGNED ( 31 downto 0 ) ; 
  
  

begin 
  
  
  SPLB : process ( F_SPLB_Clk ) 
  
  constant FOSSY_const_0_144358 : SIGNED ( 31 downto 0 ) := SIGNED' ( "00000000000000000000000000000000" ) ; 
  constant FOSSY_const_0_144357 : UNSIGNED ( 2 downto 0 ) := UNSIGNED' ( "000" ) ; 
  constant FOSSY_const_1_144376 : SIGNED ( 31 downto 0 ) := SIGNED' ( "00000000000000000000000000000001" ) ; 
  constant FOSSY_const_1_144377 : UNSIGNED ( 2 downto 0 ) := UNSIGNED' ( "001" ) ; 
  constant FOSSY_const_2_144372 : UNSIGNED ( 2 downto 0 ) := UNSIGNED' ( "010" ) ; 
  constant FOSSY_const_3_144373 : UNSIGNED ( 2 downto 0 ) := UNSIGNED' ( "011" ) ; 
  constant FOSSY_const_3435973836_144379 : UNSIGNED ( 31 downto 0 ) := UNSIGNED' ( "11001100110011001100110011001100" ) ; 
  constant FOSSY_const_4_144371 : UNSIGNED ( 2 downto 0 ) := UNSIGNED' ( "100" ) ; 
  constant FOSSY_const_5_144374 : UNSIGNED ( 2 downto 0 ) := UNSIGNED' ( "101" ) ; 
  constant FOSSY_const_53184_144375 : UNSIGNED ( 63 downto 0 ) := UNSIGNED' ( "0000000000000000000000000000000000000000000000001100111111000000" ) ; 
  constant FOSSY_const_6_144391 : UNSIGNED ( 2 downto 0 ) := UNSIGNED' ( "110" ) ; 
  constant FOSSY_const_858993459_144382 : SIGNED ( 31 downto 0 ) := SIGNED' ( "00110011001100110011001100110011" ) ; 
  variable l_Address_143319 : UNSIGNED ( 31 downto 0 ) ; 
  variable l_MasterID_143324 : UNSIGNED ( 1 downto 0 ) ; 
  variable l_Busy_143329 : UNSIGNED ( 3 downto 0 ) ; 
  variable l_BE_143334 : UNSIGNED ( 3 downto 0 ) ; 
  variable l_Buffer_143339 : UNSIGNED ( 31 downto 0 ) ; 
  variable l_LEDs_143344 : UNSIGNED ( 7 downto 0 ) ; 
  variable FOSSY_temp_tmpForSwitch_144275 : UNSIGNED ( 2 downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144276 : STD_LOGIC_VECTOR ( 1  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144277 : STD_LOGIC_VECTOR ( 3  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144278 : STD_LOGIC_VECTOR ( 3  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144279 : STD_LOGIC_VECTOR ( 3  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144280 : STD_LOGIC_VECTOR ( 3  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144281 : STD_LOGIC_VECTOR ( 3  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144282 : STD_LOGIC_VECTOR ( 1  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144283 : STD_LOGIC_VECTOR ( 3  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144284 : STD_LOGIC_VECTOR ( 3  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144285 : STD_LOGIC_VECTOR ( 7  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144286 : STD_LOGIC_VECTOR ( 15  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144287 : STD_LOGIC_VECTOR ( 3  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144288 : UNSIGNED ( 3 downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144290 : STD_LOGIC_VECTOR ( 3  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144292 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144293 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144295 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144296 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144298 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144299 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144301 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144302 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144304 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144305 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144307 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144308 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144310 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144311 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144313 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144314 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144315 : STD_LOGIC_VECTOR ( 3  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144317 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144318 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144320 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144321 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144323 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144324 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144326 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144327 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144328 : STD_LOGIC_VECTOR ( 15  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144329 : STD_LOGIC_VECTOR ( 3  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144330 : UNSIGNED ( 3 downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144332 : STD_LOGIC_VECTOR ( 3  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144334 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144335 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144337 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144338 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144340 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144341 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144343 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144344 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144346 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144347 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144349 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144350 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144352 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144353 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144355 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  variable FOSSY_temp_flatten_expr_144356 : STD_LOGIC_VECTOR ( 0  downto 0 ) ; 
  begin 
    if ( F_SPLB_Clk ' event AND F_SPLB_Clk = TRUE ) then if FOSSY_EQ_B1_B1 ( F_SPLB_Rst , TRUE ) then 
      
        SPLB_state <= FOSSY_const_0_144357 ; 
        F_Sl_addrAck <= FALSE ; 
        
          FOSSY_temp_flatten_expr_144276 := ( FOSSY_RANGE_S32_2 ( FOSSY_const_0_144358 , 1 ) ) ; 
          F_Sl_SSize <= ( UNSIGNED ( ( SIGNED ( FOSSY_temp_flatten_expr_144276 ) ) ) ) ; 
        
        F_Sl_wait <= FALSE ; 
        F_Sl_rearbitrate <= FALSE ; 
        F_Sl_wrDAck <= FALSE ; 
        F_Sl_wrComp <= FALSE ; 
        F_Sl_wrBTerm <= FALSE ; 
        F_Sl_rdDBus <= ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
        
          FOSSY_temp_flatten_expr_144277 := ( FOSSY_RANGE_S32_4 ( FOSSY_const_0_144358 , 3 ) ) ; 
          F_Sl_rdWdAddr <= ( UNSIGNED ( ( SIGNED ( FOSSY_temp_flatten_expr_144277 ) ) ) ) ; 
        
        F_Sl_rdDAck <= FALSE ; 
        F_Sl_rdComp <= FALSE ; 
        F_Sl_rdBTerm <= FALSE ; 
        
          FOSSY_temp_flatten_expr_144278 := ( FOSSY_RANGE_S32_4 ( FOSSY_const_0_144358 , 3 ) ) ; 
          F_Sl_MBusy <= ( UNSIGNED ( ( SIGNED ( FOSSY_temp_flatten_expr_144278 ) ) ) ) ; 
        
        
          FOSSY_temp_flatten_expr_144279 := ( FOSSY_RANGE_S32_4 ( FOSSY_const_0_144358 , 3 ) ) ; 
          F_Sl_MWrErr <= ( UNSIGNED ( ( SIGNED ( FOSSY_temp_flatten_expr_144279 ) ) ) ) ; 
        
        
          FOSSY_temp_flatten_expr_144280 := ( FOSSY_RANGE_S32_4 ( FOSSY_const_0_144358 , 3 ) ) ; 
          F_Sl_MRdErr <= ( UNSIGNED ( ( SIGNED ( FOSSY_temp_flatten_expr_144280 ) ) ) ) ; 
        
        
          FOSSY_temp_flatten_expr_144281 := ( FOSSY_RANGE_S32_4 ( FOSSY_const_0_144358 , 3 ) ) ; 
          F_Sl_MIRQ <= ( UNSIGNED ( ( SIGNED ( FOSSY_temp_flatten_expr_144281 ) ) ) ) ; 
        
        
          l_Address_143319 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
        
        
          
            FOSSY_temp_flatten_expr_144282 := ( FOSSY_RANGE_S32_2 ( FOSSY_const_0_144358 , 1 ) ) ; 
            l_MasterID_143324 := ( UNSIGNED ( ( SIGNED ( FOSSY_temp_flatten_expr_144282 ) ) ) ) ; 
          
        
        
          
            FOSSY_temp_flatten_expr_144283 := ( FOSSY_RANGE_S32_4 ( FOSSY_const_0_144358 , 3 ) ) ; 
            l_Busy_143329 := ( UNSIGNED ( ( SIGNED ( FOSSY_temp_flatten_expr_144283 ) ) ) ) ; 
          
        
        
          
            FOSSY_temp_flatten_expr_144284 := ( FOSSY_RANGE_S32_4 ( FOSSY_const_0_144358 , 3 ) ) ; 
            l_BE_143334 := ( UNSIGNED ( ( SIGNED ( FOSSY_temp_flatten_expr_144284 ) ) ) ) ; 
          
        
        
          l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
        
        
          
            FOSSY_temp_flatten_expr_144285 := ( FOSSY_RANGE_S32_8 ( FOSSY_const_0_144358 , 7 ) ) ; 
            l_LEDs_143344 := ( UNSIGNED ( ( SIGNED ( FOSSY_temp_flatten_expr_144285 ) ) ) ) ; 
          
        
        SPLB_state <= FOSSY_const_4_144371 ; 
      
    else 
      
        
          FOSSY_temp_tmpForSwitch_144275 := ( SPLB_state ) ; 
        
        case TO_INTEGER ( FOSSY_temp_tmpForSwitch_144275 ) is 
          when 1 => 
          
            F_Sl_addrAck <= FALSE ; 
            SPLB_state <= FOSSY_const_2_144372 ; 
          
          when 2 => 
          
            F_Sl_rdComp <= TRUE ; 
            SPLB_state <= FOSSY_const_3_144373 ; 
          
          when 3 => 
          
            F_Sl_rdDAck <= TRUE ; 
            SPLB_state <= FOSSY_const_5_144374 ; 
          
          when 4 => 
          
            if FOSSY_EQ_B1_B1 ( F_PLB_PAValid , TRUE ) then 
              
                
                  l_Address_143319 := ( F_PLB_ABus ) ; 
                
                
                  FOSSY_temp_flatten_expr_144286 := ( FOSSY_RANGE_U32_16 ( l_Address_143319 , 31 ) ) ; 
                  if FOSSY_EQ_V16_U64 ( FOSSY_temp_flatten_expr_144286 , FOSSY_const_53184_144375 ) then 
                    
                      F_Sl_addrAck <= TRUE ; 
                      
                        l_MasterID_143324 := ( F_PLB_masterID ) ; 
                      
                      
                        
                          FOSSY_temp_flatten_expr_144287 := ( FOSSY_RANGE_S32_4 ( FOSSY_const_1_144376 , 3 ) ) ; 
                          l_Busy_143329 := ( UNSIGNED ( ( SIGNED ( FOSSY_temp_flatten_expr_144287 ) ) ) ) ; 
                        
                      
                      
                        
                          FOSSY_temp_flatten_expr_144288 := ( FOSSY_SHL_U4_U2_4 ( l_Busy_143329 , l_MasterID_143324 ) ) ; 
                          l_Busy_143329 := FOSSY_temp_flatten_expr_144288 ; 
                        
                      
                      F_Sl_MBusy <= l_Busy_143329 ; 
                      if FOSSY_EQ_B1_B1 ( F_PLB_RNW , TRUE ) then 
                        
                          
                            l_Buffer_143339 := ( SPLB_Register0 ) ; 
                          
                          F_Sl_rdDBus <= l_Buffer_143339 ; 
                          SPLB_state <= FOSSY_const_1_144377 ; 
                        
                      else 
                        
                          
                            l_LEDs_143344 ( 7 downto 4 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( F_PLB_BE ) ) ) ) ) ; 
                            
                              FOSSY_temp_flatten_expr_144290 := ( FOSSY_RANGE_U8_4 ( l_LEDs_143344 , 7 ) ) ; 
                              NULL ; 
                            
                          
                          SPLB_Register0 <= ( F_PLB_wrDBus ) ; 
                          F_Sl_wrComp <= TRUE ; 
                          F_Sl_wrDAck <= TRUE ; 
                          SPLB_state <= FOSSY_const_5_144374 ; 
                        
                      end if; 
                    
                  else 
                    
                      
                        l_Buffer_143339 := ( SPLB_Register0 ) ; 
                      
                      if FOSSY_EQ_U32_U32 ( l_Buffer_143339 , FOSSY_const_3435973836_144379 ) then 
                        
                          
                            
                              FOSSY_temp_flatten_expr_144292 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                              l_LEDs_143344 ( 0 downto 0 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144292 ) ) ) ) ) ) ; 
                            
                            
                              FOSSY_temp_flatten_expr_144293 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 0 ) ) ; 
                              NULL ; 
                            
                          
                          
                            l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                          
                        
                      else 
                        if FOSSY_EQ_U32_S32 ( l_Buffer_143339 , FOSSY_const_858993459_144382 ) then 
                          
                            
                              
                                FOSSY_temp_flatten_expr_144295 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                                l_LEDs_143344 ( 1 downto 1 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144295 ) ) ) ) ) ) ; 
                              
                              
                                FOSSY_temp_flatten_expr_144296 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 1 ) ) ; 
                                NULL ; 
                              
                            
                            
                              l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                            
                          
                        else 
                          if FOSSY_GT_U32_S32 ( l_Buffer_143339 , FOSSY_const_0_144358 ) then 
                            
                              
                                
                                  FOSSY_temp_flatten_expr_144298 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                                  l_LEDs_143344 ( 2 downto 2 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144298 ) ) ) ) ) ) ; 
                                
                                
                                  FOSSY_temp_flatten_expr_144299 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 2 ) ) ; 
                                  NULL ; 
                                
                              
                              
                                l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                              
                            
                          else 
                            
                              
                                
                                  FOSSY_temp_flatten_expr_144301 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                                  l_LEDs_143344 ( 3 downto 3 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144301 ) ) ) ) ) ) ; 
                                
                                
                                  FOSSY_temp_flatten_expr_144302 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 3 ) ) ; 
                                  NULL ; 
                                
                              
                              
                                l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                              
                            
                          end if; 
                        end if; 
                      end if; 
                      if FOSSY_GT_U8_S32 ( l_LEDs_143344 , FOSSY_const_0_144358 ) then 
                        F_LEDs <= l_LEDs_143344 ; 
                      else 
                        
                      end if; 
                      SPLB_state <= FOSSY_const_6_144391 ; 
                    
                  end if; 
                
              
            else 
              
                
                  l_Buffer_143339 := ( SPLB_Register0 ) ; 
                
                if FOSSY_EQ_U32_U32 ( l_Buffer_143339 , FOSSY_const_3435973836_144379 ) then 
                  
                    
                      
                        FOSSY_temp_flatten_expr_144304 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                        l_LEDs_143344 ( 0 downto 0 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144304 ) ) ) ) ) ) ; 
                      
                      
                        FOSSY_temp_flatten_expr_144305 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 0 ) ) ; 
                        NULL ; 
                      
                    
                    
                      l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                    
                  
                else 
                  if FOSSY_EQ_U32_S32 ( l_Buffer_143339 , FOSSY_const_858993459_144382 ) then 
                    
                      
                        
                          FOSSY_temp_flatten_expr_144307 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                          l_LEDs_143344 ( 1 downto 1 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144307 ) ) ) ) ) ) ; 
                        
                        
                          FOSSY_temp_flatten_expr_144308 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 1 ) ) ; 
                          NULL ; 
                        
                      
                      
                        l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                      
                    
                  else 
                    if FOSSY_GT_U32_S32 ( l_Buffer_143339 , FOSSY_const_0_144358 ) then 
                      
                        
                          
                            FOSSY_temp_flatten_expr_144310 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                            l_LEDs_143344 ( 2 downto 2 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144310 ) ) ) ) ) ) ; 
                          
                          
                            FOSSY_temp_flatten_expr_144311 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 2 ) ) ; 
                            NULL ; 
                          
                        
                        
                          l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                        
                      
                    else 
                      
                        
                          
                            FOSSY_temp_flatten_expr_144313 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                            l_LEDs_143344 ( 3 downto 3 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144313 ) ) ) ) ) ) ; 
                          
                          
                            FOSSY_temp_flatten_expr_144314 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 3 ) ) ; 
                            NULL ; 
                          
                        
                        
                          l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                        
                      
                    end if; 
                  end if; 
                end if; 
                if FOSSY_GT_U8_S32 ( l_LEDs_143344 , FOSSY_const_0_144358 ) then 
                  F_LEDs <= l_LEDs_143344 ; 
                else 
                  
                end if; 
                SPLB_state <= FOSSY_const_6_144391 ; 
              
            end if; 
          
          when 5 => 
          
            F_Sl_addrAck <= FALSE ; 
            F_Sl_wrComp <= FALSE ; 
            F_Sl_wrDAck <= FALSE ; 
            F_Sl_rdDAck <= FALSE ; 
            F_Sl_rdComp <= FALSE ; 
            F_Sl_rdDBus <= ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
            
              
                FOSSY_temp_flatten_expr_144315 := ( FOSSY_RANGE_S32_4 ( FOSSY_const_0_144358 , 3 ) ) ; 
                l_Busy_143329 := ( UNSIGNED ( ( SIGNED ( FOSSY_temp_flatten_expr_144315 ) ) ) ) ; 
              
            
            F_Sl_MBusy <= l_Busy_143329 ; 
            
              l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
            
            
              l_Buffer_143339 := ( SPLB_Register0 ) ; 
            
            if FOSSY_EQ_U32_U32 ( l_Buffer_143339 , FOSSY_const_3435973836_144379 ) then 
              
                
                  
                    FOSSY_temp_flatten_expr_144317 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                    l_LEDs_143344 ( 0 downto 0 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144317 ) ) ) ) ) ) ; 
                  
                  
                    FOSSY_temp_flatten_expr_144318 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 0 ) ) ; 
                    NULL ; 
                  
                
                
                  l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                
              
            else 
              if FOSSY_EQ_U32_S32 ( l_Buffer_143339 , FOSSY_const_858993459_144382 ) then 
                
                  
                    
                      FOSSY_temp_flatten_expr_144320 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                      l_LEDs_143344 ( 1 downto 1 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144320 ) ) ) ) ) ) ; 
                    
                    
                      FOSSY_temp_flatten_expr_144321 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 1 ) ) ; 
                      NULL ; 
                    
                  
                  
                    l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                  
                
              else 
                if FOSSY_GT_U32_S32 ( l_Buffer_143339 , FOSSY_const_0_144358 ) then 
                  
                    
                      
                        FOSSY_temp_flatten_expr_144323 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                        l_LEDs_143344 ( 2 downto 2 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144323 ) ) ) ) ) ) ; 
                      
                      
                        FOSSY_temp_flatten_expr_144324 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 2 ) ) ; 
                        NULL ; 
                      
                    
                    
                      l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                    
                  
                else 
                  
                    
                      
                        FOSSY_temp_flatten_expr_144326 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                        l_LEDs_143344 ( 3 downto 3 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144326 ) ) ) ) ) ) ; 
                      
                      
                        FOSSY_temp_flatten_expr_144327 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 3 ) ) ; 
                        NULL ; 
                      
                    
                    
                      l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                    
                  
                end if; 
              end if; 
            end if; 
            if FOSSY_GT_U8_S32 ( l_LEDs_143344 , FOSSY_const_0_144358 ) then 
              F_LEDs <= l_LEDs_143344 ; 
            else 
              
            end if; 
            SPLB_state <= FOSSY_const_6_144391 ; 
          
          when 6 => 
          
            if FOSSY_EQ_B1_B1 ( F_PLB_PAValid , TRUE ) then 
              
                
                  l_Address_143319 := ( F_PLB_ABus ) ; 
                
                
                  FOSSY_temp_flatten_expr_144328 := ( FOSSY_RANGE_U32_16 ( l_Address_143319 , 31 ) ) ; 
                  if FOSSY_EQ_V16_U64 ( FOSSY_temp_flatten_expr_144328 , FOSSY_const_53184_144375 ) then 
                    
                      F_Sl_addrAck <= TRUE ; 
                      
                        l_MasterID_143324 := ( F_PLB_masterID ) ; 
                      
                      
                        
                          FOSSY_temp_flatten_expr_144329 := ( FOSSY_RANGE_S32_4 ( FOSSY_const_1_144376 , 3 ) ) ; 
                          l_Busy_143329 := ( UNSIGNED ( ( SIGNED ( FOSSY_temp_flatten_expr_144329 ) ) ) ) ; 
                        
                      
                      
                        
                          FOSSY_temp_flatten_expr_144330 := ( FOSSY_SHL_U4_U2_4 ( l_Busy_143329 , l_MasterID_143324 ) ) ; 
                          l_Busy_143329 := FOSSY_temp_flatten_expr_144330 ; 
                        
                      
                      F_Sl_MBusy <= l_Busy_143329 ; 
                      if FOSSY_EQ_B1_B1 ( F_PLB_RNW , TRUE ) then 
                        
                          
                            l_Buffer_143339 := ( SPLB_Register0 ) ; 
                          
                          F_Sl_rdDBus <= l_Buffer_143339 ; 
                          SPLB_state <= FOSSY_const_1_144377 ; 
                        
                      else 
                        
                          
                            l_LEDs_143344 ( 7 downto 4 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( F_PLB_BE ) ) ) ) ) ; 
                            
                              FOSSY_temp_flatten_expr_144332 := ( FOSSY_RANGE_U8_4 ( l_LEDs_143344 , 7 ) ) ; 
                              NULL ; 
                            
                          
                          SPLB_Register0 <= ( F_PLB_wrDBus ) ; 
                          F_Sl_wrComp <= TRUE ; 
                          F_Sl_wrDAck <= TRUE ; 
                          SPLB_state <= FOSSY_const_5_144374 ; 
                        
                      end if; 
                    
                  else 
                    
                      
                        l_Buffer_143339 := ( SPLB_Register0 ) ; 
                      
                      if FOSSY_EQ_U32_U32 ( l_Buffer_143339 , FOSSY_const_3435973836_144379 ) then 
                        
                          
                            
                              FOSSY_temp_flatten_expr_144334 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                              l_LEDs_143344 ( 0 downto 0 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144334 ) ) ) ) ) ) ; 
                            
                            
                              FOSSY_temp_flatten_expr_144335 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 0 ) ) ; 
                              NULL ; 
                            
                          
                          
                            l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                          
                        
                      else 
                        if FOSSY_EQ_U32_S32 ( l_Buffer_143339 , FOSSY_const_858993459_144382 ) then 
                          
                            
                              
                                FOSSY_temp_flatten_expr_144337 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                                l_LEDs_143344 ( 1 downto 1 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144337 ) ) ) ) ) ) ; 
                              
                              
                                FOSSY_temp_flatten_expr_144338 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 1 ) ) ; 
                                NULL ; 
                              
                            
                            
                              l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                            
                          
                        else 
                          if FOSSY_GT_U32_S32 ( l_Buffer_143339 , FOSSY_const_0_144358 ) then 
                            
                              
                                
                                  FOSSY_temp_flatten_expr_144340 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                                  l_LEDs_143344 ( 2 downto 2 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144340 ) ) ) ) ) ) ; 
                                
                                
                                  FOSSY_temp_flatten_expr_144341 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 2 ) ) ; 
                                  NULL ; 
                                
                              
                              
                                l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                              
                            
                          else 
                            
                              
                                
                                  FOSSY_temp_flatten_expr_144343 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                                  l_LEDs_143344 ( 3 downto 3 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144343 ) ) ) ) ) ) ; 
                                
                                
                                  FOSSY_temp_flatten_expr_144344 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 3 ) ) ; 
                                  NULL ; 
                                
                              
                              
                                l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                              
                            
                          end if; 
                        end if; 
                      end if; 
                      if FOSSY_GT_U8_S32 ( l_LEDs_143344 , FOSSY_const_0_144358 ) then 
                        F_LEDs <= l_LEDs_143344 ; 
                      else 
                        
                      end if; 
                      SPLB_state <= FOSSY_const_6_144391 ; 
                    
                  end if; 
                
              
            else 
              
                
                  l_Buffer_143339 := ( SPLB_Register0 ) ; 
                
                if FOSSY_EQ_U32_U32 ( l_Buffer_143339 , FOSSY_const_3435973836_144379 ) then 
                  
                    
                      
                        FOSSY_temp_flatten_expr_144346 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                        l_LEDs_143344 ( 0 downto 0 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144346 ) ) ) ) ) ) ; 
                      
                      
                        FOSSY_temp_flatten_expr_144347 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 0 ) ) ; 
                        NULL ; 
                      
                    
                    
                      l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                    
                  
                else 
                  if FOSSY_EQ_U32_S32 ( l_Buffer_143339 , FOSSY_const_858993459_144382 ) then 
                    
                      
                        
                          FOSSY_temp_flatten_expr_144349 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                          l_LEDs_143344 ( 1 downto 1 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144349 ) ) ) ) ) ) ; 
                        
                        
                          FOSSY_temp_flatten_expr_144350 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 1 ) ) ; 
                          NULL ; 
                        
                      
                      
                        l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                      
                    
                  else 
                    if FOSSY_GT_U32_S32 ( l_Buffer_143339 , FOSSY_const_0_144358 ) then 
                      
                        
                          
                            FOSSY_temp_flatten_expr_144352 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                            l_LEDs_143344 ( 2 downto 2 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144352 ) ) ) ) ) ) ; 
                          
                          
                            FOSSY_temp_flatten_expr_144353 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 2 ) ) ; 
                            NULL ; 
                          
                        
                        
                          l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                        
                      
                    else 
                      
                        
                          
                            FOSSY_temp_flatten_expr_144355 := ( FOSSY_RANGE_S32_1 ( FOSSY_const_1_144376 , 0 ) ) ; 
                            l_LEDs_143344 ( 3 downto 3 ) := ( UNSIGNED ( ( STD_LOGIC_VECTOR ( ( SIGNED ( FOSSY_temp_flatten_expr_144355 ) ) ) ) ) ) ; 
                          
                          
                            FOSSY_temp_flatten_expr_144356 := ( FOSSY_RANGE_U8_1 ( l_LEDs_143344 , 3 ) ) ; 
                            NULL ; 
                          
                        
                        
                          l_Buffer_143339 := ( UNSIGNED ( FOSSY_const_0_144358 ) ) ; 
                        
                      
                    end if; 
                  end if; 
                end if; 
                if FOSSY_GT_U8_S32 ( l_LEDs_143344 , FOSSY_const_0_144358 ) then 
                  F_LEDs <= l_LEDs_143344 ; 
                else 
                  
                end if; 
                SPLB_state <= FOSSY_const_6_144391 ; 
              
            end if; 
          
          when others => 
          
            NULL ; 
          
          
        end case; 
      
    end if; end if; 
  end process SPLB ; 
end architecture BEHAVIOUR;